@@ -21,7 +21,7 @@ class ConfigHelper:
     def load(self):
         # Opens the configuration file and parse it to a JSON object
         try:
-            with open(self.config_path, 'r') as config_file:
+            with open(self.config_path, 'r', encoding='utf-8') as config_file:
                 config_raw = config_file.read()
                 self._whole_config = json.loads(config_raw)
         except IOError:
