@@ -1,3 +1,4 @@
+import sys
 import shutil
 import logging
 
@@ -18,6 +19,7 @@ from moodle_dl.moodle_connector import sso_token_receiver
 from moodle_dl.moodle_connector.cookie_handler import CookieHandler
 from moodle_dl.moodle_connector.results_handler import ResultsHandler
 from moodle_dl.moodle_connector.forums_handler import ForumsHandler
+from moodle_dl.moodle_connector.quizzes_handler import QuizzesHandler
 from moodle_dl.moodle_connector.databases_handler import DatabasesHandler
 from moodle_dl.moodle_connector.assignments_handler import AssignmentsHandler
 from moodle_dl.moodle_connector.first_contact_handler import FirstContactHandler
@@ -117,7 +119,7 @@ class MoodleService:
                 Log.error(str(error))
 
         if automated is True and moodle_token is None:
-            exit(1)
+            sys.exit(1)
 
         # Saves the created token and the successful Moodle parameters.
         self.config_helper.set_property('token', moodle_token)
@@ -260,6 +262,7 @@ class MoodleService:
         download_submissions = self.config_helper.get_download_submissions()
         download_databases = self.config_helper.get_download_databases()
         download_forums = self.config_helper.get_download_forums()
+        download_quizzes = self.config_helper.get_download_quizzes()
         download_also_with_cookie = self.config_helper.get_download_also_with_cookie()
 
         courses = []
@@ -276,6 +279,7 @@ class MoodleService:
         assignments_handler = AssignmentsHandler(request_helper, version)
         databases_handler = DatabasesHandler(request_helper, version)
         forums_handler = ForumsHandler(request_helper, version)
+        quizzes_handler = QuizzesHandler(request_helper, version)
         results_handler.setVersion(version)
 
         if download_also_with_cookie:
@@ -307,6 +311,10 @@ class MoodleService:
             last_timestamps_per_forum = self.recorder.get_last_timestamps_per_forum()
             forums = forums_handler.fetch_forums_posts(forums, last_timestamps_per_forum)
 
+        quizzes = quizzes_handler.fetch_quizzes(courses)
+        if download_quizzes:
+            quizzes = quizzes_handler.fetch_quizzes_files(userid, quizzes)
+
         index = 0
         for course in courses:
             index += 1
@@ -330,7 +338,8 @@ class MoodleService:
             course_assignments = assignments.get(course.id, {})
             course_databases = databases.get(course.id, {})
             course_forums = forums.get(course.id, {})
-            results_handler.set_fetch_addons(course_assignments, course_databases, course_forums)
+            course_quizzes = quizzes.get(course.id, {})
+            results_handler.set_fetch_addons(course_assignments, course_databases, course_forums, course_quizzes)
             course.files = results_handler.fetch_files(course.id)
 
             filtered_courses.append(course)
@@ -382,6 +391,7 @@ class MoodleService:
         download_descriptions = config_helper.get_download_descriptions()
         download_links_in_descriptions = config_helper.get_download_links_in_descriptions()
         download_databases = config_helper.get_download_databases()
+        download_quizzes = config_helper.get_download_quizzes()
         exclude_file_extensions = config_helper.get_exclude_file_extensions()
         download_also_with_cookie = config_helper.get_download_also_with_cookie()
         if cookie_handler is not None:
@@ -453,6 +463,14 @@ class MoodleService:
                         course_files.append(file)
                 course.files = course_files
 
+            if not download_quizzes:
+                # Filter Quiz Files
+                course_files = []
+                for file in course.files:
+                    if not (file.module_modname.endswith('quiz') and file.deleted):
+                        course_files.append(file)
+                course.files = course_files
+
             if not download_also_with_cookie:
                 course_files = []
                 for file in course.files:
